@@ -1,4 +1,4 @@
-/*	$Id: configfile.c 15794 2009-03-18 09:10:28Z moritz $	*/
+/*	$Id: configfile.c 16319 2009-07-22 20:19:38Z moritz $	*/
 /*
  *  ezstream - source client for Icecast with external en-/decoder support
  *  Copyright (C) 2003, 2004, 2005, 2006  Ed Zaleski <oddsock@oddsock.org>
@@ -128,6 +128,19 @@ parseConfig(const char *fileName)
 				xmlFree(ls_xmlContentPtr);
 			}
 		}
+		if (!xmlStrcmp(cur->name, (const xmlChar *)"sourceuser")) {
+			if (ezConfig.username != NULL) {
+				printf("%s[%ld]: Error: Cannot have multiple <sourceuser> elements\n",
+				       fileName, xmlGetLineNo(cur));
+				config_error++;
+				continue;
+			}
+			if (cur->xmlChildrenNode != NULL) {
+				ls_xmlContentPtr = (char *)xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
+				ezConfig.username = xstrdup(ls_xmlContentPtr);
+				xmlFree(ls_xmlContentPtr);
+			}
+		}
 		if (!xmlStrcmp(cur->name, (const xmlChar *)"sourcepassword")) {
 			if (ezConfig.password != NULL) {
 				printf("%s[%ld]: Error: Cannot have multiple <sourcepassword> elements\n",
