@@ -1,13 +1,12 @@
-/*	$Id: configfile.h 15788 2009-03-17 18:20:58Z moritz $	*/
+/*	$Id: configfile.h 16319 2009-07-22 20:19:38Z moritz $	*/
 /*
  *  ezstream - source client for Icecast with external en-/decoder support
  *  Copyright (C) 2003, 2004, 2005, 2006  Ed Zaleski <oddsock@oddsock.org>
  *  Copyright (C) 2007                    Moritz Grimm <mdgrimm@gmx.net>
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU General Public License version 2 as
+ *  published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -45,6 +44,7 @@ typedef struct tag_FORMAT_ENCDEC {
 
 typedef struct tag_EZCONFIG {
 	char		*URL;
+	char		*username;
 	char		*password;
 	char		*format;
 	char		*fileName;
