@@ -1,4 +1,4 @@
-/*	$Id: ezstream.c 15795 2009-03-18 19:55:20Z moritz $	*/
+/*	$Id: ezstream.c 16537 2009-08-30 21:55:24Z moritz $	*/
 /*
  *  ezstream - source client for Icecast with external en-/decoder support
  *  Copyright (C) 2003, 2004, 2005, 2006  Ed Zaleski <oddsock@oddsock.org>
@@ -51,12 +51,14 @@ char			*__progname;
 
 int			 nFlag;
 int			 qFlag;
+int			 sFlag;
 int			 vFlag;
 int			 metadataFromProgram;
 
 EZCONFIG		*pezConfig = NULL;
 playlist_t		*playlist = NULL;
 int			 playlistMode = 0;
+unsigned int		 resource_errors = 0;
 
 #ifdef HAVE_SIGNALS
 const int		 ezstream_signals[] = {
@@ -875,8 +877,14 @@ streamFile(shout_t *shout, const char *fileName)
 	if ((filepstream = openResource(shout, fileName, &popenFlag,
 					&mdata, &isStdin, &songLen))
 	    == NULL) {
-		return (retval);
+		if (++resource_errors > 100) {
+			printf("%s: Too many errors -- giving up.\n", __progname);
+			return (0);
+		}
+		/* Continue with next resource on failure: */
+		return (1);
 	}
+	resource_errors = 0;
 
 	if (mdata != NULL) {
 		char	*tmp, *metaData;
@@ -994,9 +1002,6 @@ streamPlaylist(shout_t *shout, const char *fileName)
 		 *      bit more logical.
 		 */
 		playlist_rewind(playlist);
-		if (vFlag && playlist_get_num_items(playlist) == 0)
-			printf("%s: Warning: Playlist '%s' is empty\n",
-			       __progname, fileName);
 	}
 
 	if (!pezConfig->fileNameIsProgram && pezConfig->shuffle)
@@ -1069,6 +1074,7 @@ void
 usage(void)
 {
 	printf("usage: %s [-hnqVv] -c configfile\n", __progname);
+	printf("       %s -s [playlist]\n", __progname);
 }
 
 void
@@ -1079,6 +1085,8 @@ usageHelp(void)
 	printf("  -h             display this additional help and exit\n");
 	printf("  -n             normalize metadata strings\n");
 	printf("  -q             suppress STDERR output from external en-/decoders\n");
+	printf("  -s [playlist]  read lines from playlist (or STDIN), shuffle and print them to\n");
+	printf("                 STDOUT, then exit\n");
 	printf("  -V             print the version number and exit\n");
 	printf("  -v             verbose output (use twice for more effect)\n");
 	printf("\n");
@@ -1116,7 +1124,7 @@ main(int argc, char *argv[])
 	qFlag = 0;
 	vFlag = 0;
 
-	while ((c = local_getopt(argc, argv, "c:hnqVv")) != -1) {
+	while ((c = local_getopt(argc, argv, "c:hnqsVv")) != -1) {
 		switch (c) {
 		case 'c':
 			if (configFile != NULL) {
@@ -1136,6 +1144,9 @@ main(int argc, char *argv[])
 		case 'q':
 			qFlag = 1;
 			break;
+		case 's':
+			sFlag = 1;
+			break;
 		case 'V':
 			printf("%s\n", PACKAGE_STRING);
 			return (ez_shutdown(0));
@@ -1152,6 +1163,35 @@ main(int argc, char *argv[])
 	argc -= optind;
 	argv += optind;
 
+	if (sFlag) {
+		playlist_t	*pl;
+		const char	*entry;
+
+		switch (argc) {
+		case 0:
+			pl = playlist_read(NULL);
+			if (pl == NULL)
+				return (ez_shutdown(1));
+			break;
+		case 1:
+			pl = playlist_read(argv[0]);
+			if (pl == NULL)
+				return (ez_shutdown(1));
+			break;
+		default:
+			printf("Error: Too many arguments.\n");
+			return (ez_shutdown(2));
+		}
+
+		playlist_shuffle(pl);
+		while ((entry = playlist_get_next(pl)) != NULL)
+			printf("%s\n", entry);
+
+		playlist_free(&pl);
+
+		return (ez_shutdown(0));
+	}
+
 	if (configFile == NULL) {
 		printf("You must supply a config file with the -c argument.\n");
 		usage();
