@@ -1,4 +1,4 @@
-/*	$Id: playlist.c 15794 2009-03-18 09:10:28Z moritz $	*/
+/*	$Id: playlist.c 16536 2009-08-30 21:46:15Z moritz $	*/
 /*
  * Copyright (c) 2007, 2009 Moritz Grimm <mdgrimm@gmx.net>
  *
@@ -131,12 +131,22 @@ playlist_read(const char *filename)
 	FILE		*filep;
 	char		 buf[PATH_MAX];
 
-	pl = playlist_create(filename);
+	if (filename != NULL) {
+		pl = playlist_create(filename);
 
-	if ((filep = fopen(filename, "r")) == NULL) {
-		printf("%s: %s: %s\n", __progname, filename, strerror(errno));
-		playlist_free(&pl);
-		return (NULL);
+		if ((filep = fopen(filename, "r")) == NULL) {
+			printf("%s: %s: %s\n", __progname, filename, strerror(errno));
+			playlist_free(&pl);
+			return (NULL);
+		}
+	} else {
+		pl = playlist_create("stdin");
+
+		if ((filep = fdopen(STDIN_FILENO, "r")) == NULL) {
+			printf("%s: stdin: %s\n", __progname, strerror(errno));
+			playlist_free(&pl);
+			return (NULL);
+		}
 	}
 
 	line = 0;
@@ -147,7 +157,7 @@ playlist_read(const char *filename)
 			char skip_buf[2];
 
 			printf("%s[%lu]: File or path name too long\n",
-			       filename, line);
+			       pl->filename, line);
 			/* Discard any excess chars in that line. */
 			while (fgets(skip_buf, (int)sizeof(skip_buf), filep) != NULL) {
 				if (skip_buf[0] == '\n')
@@ -181,7 +191,7 @@ playlist_read(const char *filename)
 	}
 	if (ferror(filep)) {
 		printf("%s: playlist_read(): Error while reading %s: %s\n",
-		       __progname, filename, strerror(errno));
+		       __progname, pl->filename, strerror(errno));
 		fclose(filep);
 		playlist_free(&pl);
 		return (NULL);
@@ -499,13 +509,18 @@ playlist_run_program(playlist_t *pl)
 	}
 
 	if (fgets(buf, (int)sizeof(buf), filep) == NULL) {
-		if (ferror(filep))
-			printf("%s: Error while reading output from program '%s': %s\n",
-			       __progname, pl->filename, strerror(errno));
+		int	errnum = errno;
+
 		pclose(filep);
-		printf("%s: FATAL: External program '%s' not (or no longer) usable.\n",
-		       __progname, pl->filename);
-		exit(1);
+
+		if (ferror(filep)) {
+			printf("%s: Error while reading output from program '%s': %s\n",
+			       __progname, pl->filename, strerror(errnum));
+			exit(1);
+		}
+
+		/* No output (end of playlist.) */
+		return (NULL);
 	}
 
 	pclose(filep);
@@ -518,11 +533,9 @@ playlist_run_program(playlist_t *pl)
 
 	buf[strcspn(buf, "\n")] = '\0';
 	buf[strcspn(buf, "\r")] = '\0';
-	if (buf[0] == '\0') {
-		printf("%s: Empty line received from program '%s'\n",
-		       __progname, pl->filename);
+	if (buf[0] == '\0')
+		/* Empty line (end of playlist.) */
 		return (NULL);
-	}
 
 	if (pl->prog_track != NULL)
 		xfree(pl->prog_track);
