@@ -1,4 +1,4 @@
-/*	$Id: util.c 15794 2009-03-18 09:10:28Z moritz $	*/
+/*	$Id: util.c 16319 2009-07-22 20:19:38Z moritz $	*/
 /*
  *  ezstream - source client for Icecast with external en-/decoder support
  *  Copyright (C) 2003, 2004, 2005, 2006  Ed Zaleski <oddsock@oddsock.org>
@@ -151,6 +151,13 @@ stream_setup(const char *host, unsigned short port, const char *mount)
 		return (NULL);
 	}
 
+	if (pezConfig->username &&
+	    shout_set_user(shout, pezConfig->username) != SHOUTERR_SUCCESS) {
+		printf("%s: shout_set_user(): %s\n",
+		       __progname, shout_get_error(shout));
+		shout_free(shout);
+		return (NULL);
+	}
 	if (pezConfig->serverName &&
 	    shout_set_name(shout, pezConfig->serverName) != SHOUTERR_SUCCESS) {
 		printf("%s: shout_set_name(): %s\n",
