@@ -1,3 +1,4 @@
+/*	$Id: util.h 15788 2009-03-17 18:20:58Z moritz $	*/
 /*
  *  ezstream - source client for Icecast with external en-/decoder support
  *  Copyright (C) 2003, 2004, 2005, 2006  Ed Zaleski <oddsock@oddsock.org>
@@ -20,13 +21,15 @@
 #ifndef __UTIL_H__
 #define __UTIL_H__
 
+#include <shout/shout.h>
+
 #define ICONV_REPLACE		0
 #define ICONV_TRANSLIT		1
 #define ICONV_IGNORE		2
 
 int		strrcmp(const char *, const char *);
 int		strrcasecmp(const char *, const char *);
-shout_t *	stream_setup(const char *, const int, const char *);
+shout_t *	stream_setup(const char *, unsigned short, const char *);
 char *		CHARtoUTF8(const char *, int);
 char *		UTF8toCHAR(const char *, int);
 int		ez_gettimeofday(void *);
