@@ -1,3 +1,4 @@
+/*	$Id: xalloc.c 15794 2009-03-18 09:10:28Z moritz $	*/
 /*
  * Copyright (C) 2007  Moritz Grimm <mdgrimm@gmx.net>
  *
@@ -18,15 +19,7 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-#include <errno.h>
-#include <limits.h>
-#include <stdarg.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#include "ezstream.h"
 
 #include "xalloc.h"
 
@@ -42,27 +35,6 @@
 # undef XALLOC_SILENT
 #endif /* XALLOC_DEBUG && XALLOC_SILENT */
 
-#ifdef THREAD_SAFE
-# include <pthread.h>
-static pthread_mutex_t	 xalloc_mutex;
-static pthread_mutex_t	 strerror_mutex;
-# define XALLOC_LOCK(mtx) do {						\
-	int error;							\
-	if ((error = pthread_mutex_lock(&mtx)) != 0)			\
-		_xalloc_error(error, "XALLOC: Internal error in %s:%u: pthread_mutex_lock()", \
-			      __FILE__, __LINE__);			\
-} while (0)
-# define XALLOC_UNLOCK(mtx) do {					\
-	int error;							\
-	if ((error = pthread_mutex_unlock(&mtx)) != 0)			\
-		_xalloc_error(error, "XALLOC: Internal error in %s:%u: pthread_mutex_unlock()", \
-			      __FILE__, __LINE__);			\
-} while (0)
-#else
-# define XALLOC_LOCK(mtx)	((void)0)
-# define XALLOC_UNLOCK(mtx)	((void)0)
-#endif /* THREAD_SAFE */
-
 #ifdef XALLOC_DEBUG
 # include <sys/tree.h>
 
@@ -169,13 +141,8 @@ _xalloc_error(int errnum, const char *fmt, ...)
 	va_start(ap, fmt);
 #ifndef XALLOC_SILENT
 	vfprintf(debug_output, fmt, ap);
-	if (errnum > 0) {
-		if (xalloc_initialized)
-			XALLOC_LOCK(strerror_mutex);
+	if (errnum > 0)
 		fprintf(debug_output, ": %s\n", strerror(errnum));
-		if (xalloc_initialized)
-			XALLOC_UNLOCK(strerror_mutex);
-	}
 	fflush(debug_output);
 #endif /* !XALLOC_SILENT */
 	va_end(ap);
@@ -291,10 +258,6 @@ _xalloc_vasprintf(char **str_p, const char *fmt, va_list ap, size_t *strsiz)
 void
 xalloc_initialize_debug(unsigned int level, FILE *output)
 {
-#ifdef THREAD_SAFE
-	int	err;
-#endif /* THREAD_SAFE */
-
 	if (xalloc_initialized)
 		_xalloc_fatal("XALLOC: xalloc_initialize(): Xalloc library already initialized\n");
 
@@ -314,13 +277,6 @@ xalloc_initialize_debug(unsigned int level, FILE *output)
 	xalloc_peak = 0;
 	xalloc_freed = 0;
 
-#ifdef THREAD_SAFE
-	if ((err = pthread_mutex_init(&strerror_mutex, NULL)) != 0)
-		_xalloc_error(err, "XALLOC: xalloc_initialize(): Initializing xalloc_mutex");
-	if ((err = pthread_mutex_init(&xalloc_mutex, NULL)) != 0)
-		_xalloc_error(err, "XALLOC: xalloc_initialize(): Initializing strerror_mutex");
-#endif /* THREAD_SAFE */
-
 	xalloc_initialized = 1;
 }
 
@@ -338,12 +294,10 @@ xalloc_set_functions(void *(*malloc_func)(size_t),
 	    realloc_func == NULL)
 		_xalloc_fatal("XALLOC: xalloc_set_functions(): Bad argument(s)\n");
 
-	XALLOC_LOCK(xalloc_mutex);
 	real_malloc = malloc_func;
 	real_calloc = calloc_func;
 	real_realloc = realloc_func;
 	real_free = free_func;
-	XALLOC_UNLOCK(xalloc_mutex);
 }
 
 void
@@ -357,8 +311,6 @@ xalloc_shutdown(void)
 		struct memory	*mem, *mem_next;
 		size_t		 leaked_bytes = 0;
 
-		XALLOC_LOCK(xalloc_mutex);
-
 		for (mem = RB_MIN(memory_tree, &memory_tree_head);
 		     mem != NULL;
 		     mem = mem_next) {
@@ -394,20 +346,9 @@ xalloc_shutdown(void)
 				     (unsigned long)xalloc_peak,
 				     (unsigned long)xalloc_freed,
 				     (unsigned long)xalloc_total);
-
-		XALLOC_UNLOCK(xalloc_mutex);
 	}
 #endif /* XALLOC_DEBUG */
 
-#ifdef THREAD_SAFE
-	if (pthread_mutex_destroy(&xalloc_mutex) != 0)
-		_xalloc_fatal("XALLOC: Internal error: xalloc_shutdown(): xalloc_mutex %p cannot be destroyed\n",
-			      xalloc_mutex);
-	if (pthread_mutex_destroy(&strerror_mutex) != 0)
-		_xalloc_fatal("XALLOC: Internal error: xalloc_shutdown(): strerror_mutex %p cannot be destroyed\n",
-			      strerror_mutex);
-#endif /* THREAD_SAFE */
-
 	xalloc_initialized = 0;
 }
 
@@ -441,7 +382,6 @@ xmalloc_c(size_t size, const char *file, unsigned int line)
 		else
 			mem->allocated_by = unknown_file;
 		mem->allocated_in_line = line;
-		XALLOC_LOCK(xalloc_mutex);
 		mem->id = ++xalloc_next_id;
 		if ((mem_exists = RB_INSERT(memory_tree, &memory_tree_head, mem)) != NULL) {
 			/* Freed pointer is being reused: */
@@ -456,7 +396,6 @@ xmalloc_c(size_t size, const char *file, unsigned int line)
 		xalloc_total += size;
 		if (xalloc_allocated > xalloc_peak)
 			xalloc_peak = xalloc_allocated;
-		XALLOC_UNLOCK(xalloc_mutex);
 	}
 #endif /* XALLOC_DEBUG */
 
@@ -498,7 +437,6 @@ xcalloc_c(size_t nmemb, size_t size, int may_fail,
 		else
 			mem->allocated_by = unknown_file;
 		mem->allocated_in_line = line;
-		XALLOC_LOCK(xalloc_mutex);
 		mem->id = ++xalloc_next_id;
 		if ((mem_exists = RB_INSERT(memory_tree, &memory_tree_head, mem)) != NULL) {
 			/* Freed pointer is being reused: */
@@ -513,7 +451,6 @@ xcalloc_c(size_t nmemb, size_t size, int may_fail,
 		xalloc_total += nmemb * size;
 		if (xalloc_allocated > xalloc_peak)
 			xalloc_peak = xalloc_allocated;
-		XALLOC_UNLOCK(xalloc_mutex);
 	}
 #endif /* XALLOC_DEBUG */
 
@@ -548,9 +485,7 @@ xrealloc_c(void *ptr, size_t nmemb, size_t size,
 			if ((mem = real_calloc(1, sizeof(struct memory))) == NULL)
 				_xalloc_error(errno, "XALLOC: Internal error");
 			mem->ptr = ret;
-			XALLOC_LOCK(xalloc_mutex);
 			mem->id = ++xalloc_next_id;
-			XALLOC_UNLOCK(xalloc_mutex);
 			if (file)
 				mem->allocated_by = file;
 			else
@@ -562,7 +497,6 @@ xrealloc_c(void *ptr, size_t nmemb, size_t size,
 #ifdef XALLOC_DEBUG
 		struct memory	find_mem;
 
-		XALLOC_LOCK(xalloc_mutex);
 		if (debug_level > 0) {
 			find_mem.ptr = ptr;
 			if ((mem = RB_FIND(memory_tree, &memory_tree_head, &find_mem)) == NULL)
@@ -571,7 +505,6 @@ xrealloc_c(void *ptr, size_t nmemb, size_t size,
 					      line, ptr);
 			RB_REMOVE(memory_tree, &memory_tree_head, mem);
 		}
-		XALLOC_UNLOCK(xalloc_mutex);
 #endif /* XALLOC_DEBUG */
 		ret = real_realloc(ptr, nsiz);
 #ifdef XALLOC_DEBUG
@@ -596,7 +529,6 @@ xrealloc_c(void *ptr, size_t nmemb, size_t size,
 		struct memory	*mem_exists;
 		ssize_t 	 diff = (ssize_t)(nsiz - mem->size);
 
-		XALLOC_LOCK(xalloc_mutex);
 		xalloc_allocated += diff;
 		if (diff < 0)
 			xalloc_freed += -diff;
@@ -614,7 +546,6 @@ xrealloc_c(void *ptr, size_t nmemb, size_t size,
 			_memory_free(&mem_exists);
 			RB_INSERT(memory_tree, &memory_tree_head, mem);
 		}
-		XALLOC_UNLOCK(xalloc_mutex);
 	}
 #endif /* XALLOC_DEBUG */
 
@@ -658,7 +589,6 @@ xfree_c(void **ptr_p, const char *file, unsigned int line)
 	if (debug_level > 0) {
 		struct memory	*mem = NULL, find_mem;
 
-		XALLOC_LOCK(xalloc_mutex);
 		find_mem.ptr = *ptr_p;
 		if ((mem = RB_FIND(memory_tree, &memory_tree_head, &find_mem)) == NULL)
 			_xalloc_fatal("XALLOC: xfree(): %s:%u: Junk pointer %p not accounted for\n",
@@ -695,7 +625,6 @@ xfree_c(void **ptr_p, const char *file, unsigned int line)
 			RB_REMOVE(memory_tree, &memory_tree_head, mem);
 			_memory_free(&mem);
 		}
-		XALLOC_UNLOCK(xalloc_mutex);
 	}
 #endif /* XALLOC_DEBUG */
 
@@ -743,7 +672,6 @@ xasprintf_c(const char *file, unsigned int line,
 		else
 			mem->allocated_by = unknown_file;
 		mem->allocated_in_line = line;
-		XALLOC_LOCK(xalloc_mutex);
 		mem->id = ++xalloc_next_id;
 		if ((mem_exists = RB_INSERT(memory_tree, &memory_tree_head, mem)) != NULL) {
 			/* Freed pointer is being reused: */
@@ -758,7 +686,6 @@ xasprintf_c(const char *file, unsigned int line,
 		xalloc_total += strsiz;
 		if (xalloc_allocated > xalloc_peak)
 			xalloc_peak = xalloc_allocated;
-		XALLOC_UNLOCK(xalloc_mutex);
 	}
 # endif /* XALLOC_DEBUG */
 
